@@ -2,6 +2,6 @@
 Screens for browsr
 """
 
-from ctx.screens.code_browser import CodeBrowserScreen
+from ctxflow.screens.code_browser import CodeBrowserScreen
 
 __all__ = ["CodeBrowserScreen"]
